@@ -1,7 +1,7 @@
 /*
  * GfarmFS-FUSE for Gfarm version 2
  *
- * $Id: gfarm2fs.c 8985 2014-03-23 07:49:58Z tatebe $
+ * $Id: gfarm2fs.c 9788 2015-07-03 04:09:45Z tatebe $
  */
 
 #include "config.h"
@@ -2065,6 +2065,8 @@ main(int argc, char *argv[])
 #endif
 	/* use inum in Gfarm */
 	fuse_opt_add_arg(&args, "-ouse_ino");
+	/* immediate removal */
+	fuse_opt_add_arg(&args, "-ohard_remove");
 	if (params.mount_point == NULL) {
 		fprintf(stderr, "missing mountpoint\n");
 		fprintf(stderr, "see `%s -h' for usage\n", program_name);
